drain-swamp list
=================

List the snippets within Sphinx conf.py

Normal usage
-------------

From package base folder

.. code-block:: shell

   drain-swamp list

Command options
""""""""""""""""

.. csv-table:: :code:`drain-swamp list` options
   :header: cli, default, description
   :widths: auto

   "-p/--path", "cwd", "absolute path to package base folder"

From source code
------------------

.. code-block:: shell

   python src/drain_swamp/cli_igor.py list
